
{% extends 'base.html' %}

{% load i18n widget_tweaks %}


{% block content %}

    <div class="container">
        <div class="row">
            <div class="col-md-6 col-md-offset-3 col-sm-6 col-sm-offset-3 col-xs-12">
                <h2>{% trans 'Вхід на сайт' %}</h2>

                <form id="login-form" method="post">

                    {% csrf_token %}

                    {{ form.errors }}
                    {{ form.non_field_errors }}

                    <div class="input-group">
                        <span class="input-group-addon">
                            <span class="input-icon input-icon-email"></span>
                            <span class="input-text">{{ form.username.label }} *</span>
                        </span>
                        {{ form.username|add_class:"form-control input-lg" }}
                        <div class="help-block">{{ form.username.errors }}</div>
                    </div>

                    <div class="input-group">
                        <span class="input-group-addon">
                            <span class="input-icon input-icon-password"></span>
                            <span class="input-text">{{ form.password.label }} *</span>
                        </span>
                        {{ form.password|add_class:"form-control input-lg" }}
                        <div class="help-block">{{ form.password.errors }}</div>
                    </div>

                    <div class="row m-b-10">
                        <div class="col-sm-6">
                            {{ form.remember.label_tag }} {{ form.remember }}
                        </div>
                        <div class="col-sm-6 text-right">
                            <a href="{% url 'accounts:password-reset' %}">
                                {% trans 'Забули Ваш пароль' %} ?
                            </a>
                        </div>
                    </div>

                    <button class="btn btn-block btn-custom-2">{% trans 'Увійти' %}</button>
                </form>
            </div>
        </div>
    </div>

{% endblock %}
