
{% extends 'accounts/base-email.html' %}

{% load i18n %}


{% block header %}
    {% trans 'Відновлення паролю на' %} {{ domain }}
{% endblock %}


{% block content %}
    {% trans 'Щоб відновити пароль на сайті' %} {{ domain }} {% trans 'натисніть тут' %}:
    <a href="{{ protocol }}://{{ domain }}{% url 'accounts:password-reset-confirm' uidb64=uid token=token %}">
        {{ protocol }}://{{ domain }}{% url 'accounts:password-reset-confirm' uidb64=uid token=token %}
    </a>

    <br /><br />

    {% trans 'З повагою' %}, <br /> {% trans 'адміністрація сайту' %} {{ domain }}.
{% endblock %}
