<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
</head>
<body>

    <style>
        body {
            background: #eadedd;
        }

        .container {
            width: 600px;
            display: block;
            margin: 0 auto;
            border: 1px solid #868281;
            border-radius: 3px;
        }

        .header {
            background: #c32b1c;
            padding: 20px 10px;
            font-size: 20px;
            color: #fff;
            font-weight: bold;
        }

        .content {
            padding: 30px 10px;
            background: #fff;
            color: #58504e;
        }
    </style>

    <div class="container">
        <div class="header">
            {% block header %}{% endblock %}
        </div>
        <div class="content">
            {% block content %}{% endblock %}
        </div>
    </div>

</body>
</html>